/* 
 * tclAppInit.c --
 *
 *	Provides a default version of the Tcl_AppInit procedure.
 *
 */

#include <pvmInt.h>

/*
 * For the following functions there are Pvm-equivalents in the library
 * that should be used instead of the Tk-functions if Tk is not present.
 */

void
#ifdef __cplusplus
Tk_CreateFileHandler (	int fd,
			int mask,		
			Tk_FileProc *proc,
			ClientData clientData)
#else
Tk_CreateFileHandler(fd, mask, proc, clientData)
			int fd;
			int mask;
			Tk_FileProc *proc;
			ClientData clientData;
#endif
{
    Pvm_CreateFileHandler(fd, mask, proc, clientData);
}

void
#ifdef __cplusplus
Tk_DeleteFileHandler (int fd)
#else
Tk_DeleteFileHandler(fd)
 		      int fd;
#endif
{
    Pvm_DeleteFileHandler(fd);
}

void
#ifdef __cplusplus
Tk_DoWhenIdle ( Tk_IdleProc *proc,
		ClientData clientData)
#else
Tk_DoWhenIdle(proc, clientData)
		Tk_IdleProc *proc;
		ClientData clientData;
#endif
{
    Pvm_DoWhenIdle(proc, clientData);
}

void
#ifdef __cplusplus
Tk_BackgroundError (Tcl_Interp *interp)
#else
Tk_BackgroundError(interp)
		    Tcl_Interp *interp;
#endif
{
    Pvm_BackgroundError(interp);
}

/*
 * The following variable is a special hack that is needed in order for
 * Sun shared libraries to be used for Tcl.
 */

EXTERN int matherr();
int (*tclDummyMathPtr)() = matherr;

/*
 *----------------------------------------------------------------------
 *
 * main --
 *
 *	This is the main program for the application.
 *
 * Results:
 *	None: Pvm_Main never returns here, so this procedure never
 *	returns either.
 *
 * Side effects:
 *	Whatever the application does.
 *
 *----------------------------------------------------------------------
 */

#ifdef __cplusplus
int
main (int    argc,		/* Number of command-line arguments. */
      char **argv)		/* Values of command-line arguments. */
#else
int
main(argc, argv)
    int argc;			/* Number of command-line arguments. */
    char **argv;		/* Values of command-line arguments. */
#endif
{
    Pvm_Main(argc, argv, Tcl_AppInit);
    return 0;			/* Needed only to prevent compiler warning. */
}

/*
 *----------------------------------------------------------------------
 *
 * Tcl_AppInit --
 *
 *	This procedure performs application-specific initialization.
 *	Most applications, especially those that incorporate additional
 *	packages, will have their own version of this procedure.
 *
 * Results:
 *	Returns a standard Tcl completion code, and leaves an error
 *	message in interp->result if an error occurs.
 *
 * Side effects:
 *	Depends on the startup script.
 *
 *----------------------------------------------------------------------
 */
#ifdef __cplusplus
int
Tcl_AppInit (Tcl_Interp *interp)
#else
int
Tcl_AppInit(interp)
    Tcl_Interp *interp;
#endif
{
    if (Tcl_Init(interp) == TCL_ERROR) {
	return TCL_ERROR;
    }

    /*
     * Call the init procedures for included packages.  Each call should
     * look like this:
     *
     * if (Mod_Init(interp) == TCL_ERROR) {
     *     return TCL_ERROR;
     * }
     *
     * where "Mod" is the name of the module.
     */

    if (Pvm_Init(interp) == TCL_ERROR) {
	return TCL_ERROR;
    }

    /*
     * Call Tcl_CreateCommand for application-specific commands, if
     * they weren't already created by the init procedures called above.
     */

    /*
     * Specify a user-specific startup file to invoke if the application
     * is run interactively.  Typically the startup file is "~/.apprc"
     * where "app" is the name of the application.  If this line is deleted
     * then no user-specific startup file will be run under any conditions.
     */

    tcl_RcFileName = "~/.pvmrc";
    return TCL_OK;
}
